@@ -21,7 +21,7 @@ Boston, MA 02111-1307, USA.
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.5 2005/04/15 20:57:11 evertonm Exp $
+  $Id: main.c,v 1.7 2005/07/08 20:04:55 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -31,6 +31,14 @@ Boston, MA 02111-1307, USA.
 #include <oop.h>
 #include <assert.h>
 
+#ifdef NEPIM_SOLARIS
+# include <signal.h>
+typedef void (*sighandler_t)(int);
+#else
+# define __USE_GNU /* for sighandler_t in <signal.h> */
+# include <signal.h>
+#endif /* NEPIM_SOLARIS */
+
 #include "conf.h"
 #include "common.h"
 
@@ -90,6 +98,10 @@ static void usage(FILE *out, const char *prog_name)
 
 static void init_event_loop()
 {
+  sighandler_t handler;
+  handler = signal(SIGPIPE, SIG_IGN);
+  assert(handler != SIG_ERR);
+
   nepim_global.oop_sys = oop_sys_new();
   assert(nepim_global.oop_sys);
   nepim_global.oop_src = oop_sys_source(nepim_global.oop_sys);
