@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: pipe.c,v 1.1.1.1 2005/04/09 22:51:43 evertonm Exp $ */
+/* $Id: pipe.c,v 1.2 2005/04/19 03:40:33 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -80,6 +80,10 @@ void nepim_pipe_set_add(nepim_pipe_set_t *set, int sd,
     pipe->test_duration      = test_duration;
     pipe->write_delay        = write_delay;
     pipe->duration_done      = 0;
+    pipe->total_reads        = 0;
+    pipe->total_writes       = 0;
+    pipe->interval_reads     = 0;
+    pipe->interval_writes    = 0;
     pipe->byte_total_sent    = 0;
     pipe->byte_total_recv    = 0;
     pipe->byte_interval_sent = 0;
