@@ -19,13 +19,14 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: udp_server.c,v 1.3 2005/05/30 22:07:14 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.4 2005/06/21 13:13:48 evertonm Exp $ */
 
 
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
+#include <errno.h>
 #include <oop.h>
 
 #include "conf.h"
@@ -33,9 +34,35 @@ Boston, MA 02111-1307, USA.
 
 
 static void *on_udp_segment(oop_source *src, int sd,
-			    oop_event event, void *unnused)
+                            oop_event event, void *unnused)
 {
-  fprintf(stderr, "FIXME: %s %s\n", __FILE__, __PRETTY_FUNCTION__);
+  int rd;
+  char buf[nepim_global.udp_read_size];
+  union {
+    struct sockaddr_in inet;
+    struct sockaddr_in6 inet6;
+  } from;
+  socklen_t fromlen = sizeof(from);
+
+  rd = recvfrom(sd, buf, nepim_global.udp_read_size, 0, 
+		(struct sockaddr *) &from, &fromlen);
+  if (rd < 1) {
+    switch (errno) {
+    case EINTR:
+      fprintf(stderr, "recvfrom: EINTR on UDP socket %d\n", sd);
+      return OOP_CONTINUE;
+    case EAGAIN:
+      fprintf(stderr, "recvfrom: EAGAIN on UDP socket %d\n", sd);
+      return OOP_CONTINUE;
+    }
+
+    fprintf(stderr, "recvfrom: failure on UDP socket %d\n", sd);
+
+    return OOP_CONTINUE;
+  }
+
+  fprintf(stderr, "FIXME: %s %s recv=%d bytes\n", 
+          __FILE__, __PRETTY_FUNCTION__, rd);
 
   return OOP_CONTINUE;
 }
